[![PyPI version](https://badge.fury.io/py/easys-ordermanager.svg)](https://badge.fury.io/py/easys-ordermanager)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/Lektor.svg)](https://pypi.org/project/easys-ordermanager/)
[![Travis CI build status](https://travis-ci.org/RegioHelden/easys-ordermanager.svg)](https://travis-ci.org/RegioHelden/easys-ordermanager)
[![Coverage Status](https://coveralls.io/repos/github/RegioHelden/easys-ordermanager/badge.svg?branch=add_coveralls)](https://coveralls.io/github/RegioHelden/easys-ordermanager?branch=add_coveralls)

# EasyS order manager API

Compatible with
- Django Rest Framework: 3.8, 3.9, 3.10, 3.11
- Django: 1.11, 2.2 (Not yet for 3.x)
- Python: 3.6, 3.7, 3.8
